<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
         "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html>
<head>
  <meta http-equiv="content-type" content="text/html; charset=utf-8" />
  <title><% $ARGS{title} %></title>
  <link rel="stylesheet" href="style.css" type="text/css" />
  <link rel="top"        href="index.html" />
  <link rel="next"       href="<% $ARGS{next} %>" />
  <script type="text/javascript" src="space_next.js"></script>
</head>
<body id="index">

  <h1>&nbsp;</h1>

  <div id="title-panel">
  <div id="title-header"><% $ARGS{title} %></div>
% if($ARGS{subtitle}) {
  <div id="title-subtitle"><% $ARGS{subtitle} %></div>
% }
  </div>

  <div id="title-author">
    <% $ARGS{author} %><br />
% if($ARGS{email}) {
    &lt;<% $ARGS{email} %>&gt;
% }
  </div>

  <div id="title-logo"></div>

  <div id="nav"><a id="nav-next" href="<% $ARGS{next} %>"><img
  src="images/nav_next.png" alt="Next" /></a></div>

  <ul id="footer">
% if($ARGS{event}) {
    <li><% $ARGS{event} %></li>
% }
% if($ARGS{date}) {
    <li><% $ARGS{date} %></li>
% }
  </ul>

</body>
</html>
